Welcome to PyActiveStorage Documentation!
=========================================

.. include:: _sidebar.rst.inc

.. _fig_how_it_works:
.. figure:: /figures/PyActiveStorage-logo-complete.jpg
   :align: center
   :width: 80%

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
